emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r111414: Merge from gnulib.


From: Paul Eggert
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r111414: Merge from gnulib.
Date: Thu, 03 Jan 2013 18:17:49 -0800
User-agent: Bazaar (2.5.0)

------------------------------------------------------------
revno: 111414
committer: Paul Eggert <address@hidden>
branch nick: trunk
timestamp: Thu 2013-01-03 18:17:49 -0800
message:
  Merge from gnulib.
  
  This incorporates:
  2013-01-04 stdio: remove now-unnecessary stdio.c
  2013-01-04 fprintftime: depend on stdio, not ignore-value
  2013-01-04 fwrite: silence __wur only for older glibc versions
  2013-01-04 fwrite: silence __wur without using inline
  * lib/stdio.c: Remove.
  * lib/stdio.in.h, lib/strftime.c: Update from gnulib.
  * lib/gnulib.mk, m4/gnulib-comp.m4: Regenerate.
removed:
  lib/stdio.c
modified:
  ChangeLog
  lib/gnulib.mk
  lib/stdio.in.h
  lib/strftime.c
  m4/gnulib-comp.m4
=== modified file 'ChangeLog'
--- a/ChangeLog 2013-01-02 16:37:04 +0000
+++ b/ChangeLog 2013-01-04 02:17:49 +0000
@@ -1,3 +1,14 @@
+2013-01-04  Paul Eggert  <address@hidden>
+
+       Merge from gnulib, incorporating:
+       2013-01-04 stdio: remove now-unnecessary stdio.c
+       2013-01-04 fprintftime: depend on stdio, not ignore-value
+       2013-01-04 fwrite: silence __wur only for older glibc versions
+       2013-01-04 fwrite: silence __wur without using inline
+       * lib/stdio.c: Remove.
+       * lib/stdio.in.h, lib/strftime.c: Update from gnulib.
+       * lib/gnulib.mk, m4/gnulib-comp.m4: Regenerate.
+
 2013-01-02  Paul Eggert  <address@hidden>
 
        Merge from gnulib, incorporating copyright-date changes and:

=== modified file 'lib/gnulib.mk'
--- a/lib/gnulib.mk     2013-01-02 16:37:04 +0000
+++ b/lib/gnulib.mk     2013-01-04 02:17:49 +0000
@@ -774,7 +774,6 @@
 ## begin gnulib module stdio
 
 BUILT_SOURCES += stdio.h
-libgnu_a_SOURCES += stdio.c
 
 # We need the following in order to create <stdio.h> when the system
 # doesn't have one that works with the given compiler.

=== removed file 'lib/stdio.c'
--- a/lib/stdio.c       2012-11-30 18:25:59 +0000
+++ b/lib/stdio.c       1970-01-01 00:00:00 +0000
@@ -1,3 +0,0 @@
-#include <config.h>
-#define _GL_STDIO_INLINE _GL_EXTERN_INLINE
-#include "stdio.h"

=== modified file 'lib/stdio.in.h'
--- a/lib/strftime.c    2013-01-01 09:11:05 +0000
+++ b/lib/strftime.c    2013-01-04 02:17:49 +0000
@@ -26,7 +26,6 @@
 #else
 # include <config.h>
 # if FPRINTFTIME
-#  include "ignore-value.h"
 #  include "fprintftime.h"
 # else
 #  include "strftime.h"
@@ -209,15 +208,7 @@
          else if (to_uppcase)                                                 \
            fwrite_uppcase (p, (s), _n);                                       \
          else                                                                 \
-           {                                                                  \
-             /* We are ignoring the value of fwrite here, in spite of the     \
-                fact that technically, that may not be valid: the fwrite      \
-                specification in POSIX 2008 defers to that of fputc, which    \
-                is intended to be consistent with the one from ISO C,         \
-                which permits failure due to ENOMEM *without* setting the     \
-                stream's error indicator.  */                                 \
-             ignore_value (fwrite ((s), _n, 1, p));                           \
-           }                                                                  \
+           fwrite (s, _n, 1, p);                                              \
        }                                                                      \
      while (0)                                                                \
     )

=== modified file 'm4/gnulib-comp.m4'
--- a/m4/gnulib-comp.m4 2013-01-02 16:37:04 +0000
+++ b/m4/gnulib-comp.m4 2013-01-04 02:17:49 +0000
@@ -712,7 +712,6 @@
   lib/stdbool.in.h
   lib/stddef.in.h
   lib/stdint.in.h
-  lib/stdio.c
   lib/stdio.in.h
   lib/stdlib.in.h
   lib/strftime.c


reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- a/lib/stdio.in.h    2013-01-02 16:37:04 +0000
+++ b/lib/stdio.in.h    2013-01-04 02:17:49 +0000
@@ -46,11 +46,6 @@
 #ifndef address@hidden@_STDIO_H
 #define address@hidden@_STDIO_H
 
-_GL_INLINE_HEADER_BEGIN
-#ifndef _GL_STDIO_INLINE
-# define _GL_STDIO_INLINE _GL_INLINE
-#endif
-
 /* Get va_list.  Needed on many systems, including glibc 2.8.  */
 #include <stdarg.h>
 
@@ -580,21 +575,17 @@
 _GL_CXXALIAS_SYS (fwrite, size_t,
                   (const void *ptr, size_t s, size_t n, FILE *stream));
 
 /* Work around glibc bug 11959
    <http://sources.redhat.com/bugzilla/show_bug.cgi?id=11959>,
    which sometimes causes an unwanted diagnostic for fwrite calls.
-   This affects only function declaration attributes, so it's not
-   needed for C++.  */
-#  if !defined __cplusplus && 0 < __USE_FORTIFY_LEVEL
-_GL_STDIO_INLINE size_t _GL_ARG_NONNULL ((1, 4))
-rpl_fwrite (const void *ptr, size_t s, size_t n, FILE *stream)
-{
-  size_t r = fwrite (ptr, s, n, stream);
-  (void) r;
-  return r;
-}
+   This affects only function declaration attributes under certain
+   versions of gcc, and is not needed for C++.  */
+#  if (0 < __USE_FORTIFY_LEVEL                                          \
+       && __GLIBC__ == 2 && 4 <= __GLIBC_MINOR__ && __GLIBC_MINOR__ <= 15 \
+       && 3 < __GNUC__ + (4 <= __GNUC_MINOR__)                          \
+       && !defined __cplusplus)
 #   undef fwrite
-#   define fwrite rpl_fwrite
+#   define fwrite(a, b, c, d) ({size_t __r = fwrite (a, b, c, d); __r; })
 #  endif
 # endif
 _GL_CXXALIASWARN (fwrite);
@@ -1338,8 +1329,6 @@
                       "POSIX compliance");
 #endif
 
-_GL_INLINE_HEADER_END
-
 #endif /* address@hidden@_STDIO_H */
 #endif /* address@hidden@_STDIO_H */
 #endif
@@ -580,21 +575,17 @@
                   (const void *ptr, size_t s, size_t n, FILE *stream));
 
-/* Work around glibc bug 11959
+/* Work around bug 11959 when fortifying glibc 2.4 through 2.15
    <http://sources.redhat.com/bugzilla/show_bug.cgi?id=11959>,
    which sometimes causes an unwanted diagnostic for fwrite calls.

=== modified file 'lib/strftime.c'